MOFBench
-----------

Base classes
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: mofdscribe.bench.mofbench
    :members:


The results are reported in :code:`pydantic` model with the following fields:

.. pydantic:: mofdscribe.bench.mofbench.BenchResult


logarithmic CO2 Henry coefficient
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: mofdscribe.bench.logkHCO2
    :members:


PBE bandgap
^^^^^^^^^^^^^^^

.. automodule:: mofdscribe.bench.pbegap
    :members:

Methane deliverable capacity
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: mofdscribe.bench.ch4dc
    :members:


Dummy Models 
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: mofdscribe.bench.dummy_models
    :members: